==> zio-aws-chimesdkmediapipelines_2.12-7.21.15.8-sources.jar: zio/aws/chimesdkmediapipelines/model/ListMediaPipelineKinesisVideoStreamPoolsRequest.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.chimesdkmediapipelines.model.primitives.ResultMax
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListMediaPipelineKinesisVideoStreamPoolsRequest(
    nextToken: Optional[String] = Optional.Absent,
    maxResults: Optional[ResultMax] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest = {
    import ListMediaPipelineKinesisVideoStreamPoolsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        maxResults.map(value => ResultMax.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
      .wrap(buildAwsValue())
}
object ListMediaPipelineKinesisVideoStreamPoolsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest =
      zio.aws.chimesdkmediapipelines.model
        .ListMediaPipelineKinesisVideoStreamPoolsRequest(
          nextToken.map(value => value),
          maxResults.map(value => value)
        )
    def nextToken: Optional[String]
    def maxResults: Optional[ResultMax]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, ResultMax] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
  ) extends zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest.ReadOnly {
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val maxResults: Optional[ResultMax] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.chimesdkmediapipelines.model.primitives.ResultMax(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
  ): zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmediapipelines_3-7.21.15.5-sources.jar: zio/aws/chimesdkmediapipelines/model/ListMediaPipelineKinesisVideoStreamPoolsRequest.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.chimesdkmediapipelines.model.primitives.ResultMax
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListMediaPipelineKinesisVideoStreamPoolsRequest(
    nextToken: Optional[String] = Optional.Absent,
    maxResults: Optional[ResultMax] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest = {
    import ListMediaPipelineKinesisVideoStreamPoolsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        maxResults.map(value => ResultMax.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
      .wrap(buildAwsValue())
}
object ListMediaPipelineKinesisVideoStreamPoolsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest =
      zio.aws.chimesdkmediapipelines.model
        .ListMediaPipelineKinesisVideoStreamPoolsRequest(
          nextToken.map(value => value),
          maxResults.map(value => value)
        )
    def nextToken: Optional[String]
    def maxResults: Optional[ResultMax]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, ResultMax] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
  ) extends zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest.ReadOnly {
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val maxResults: Optional[ResultMax] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.chimesdkmediapipelines.model.primitives.ResultMax(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest
  ): zio.aws.chimesdkmediapipelines.model.ListMediaPipelineKinesisVideoStreamPoolsRequest.ReadOnly =
    new Wrapper(impl)
}
